package po

import (
	"encoding/json"
	"fmt"
	"gitea.cdlsxd.cn/BaseSystem/plugin/proto"
	"plugins/alipay_redpack/internal/vo"
)

type PayeeInfo struct {
	Identity     string `validate:"required" json:"identity"`
	IdentityType string `validate:"required" json:"identity_type"`
}

type BusinessParams struct {
	SubBizScene string `json:"sub_biz_scene"`
}

func (b *BusinessParams) ToString() string {
	s, _ := json.Marshal(b)
	return string(s)
}

type OrderReq struct {
	OutBizNo       string     `validate:"required" json:"out_biz_no"`
	TransAmount    string     `validate:"required" json:"trans_amount"`
	ProductCode    string     `validate:"required" json:"product_code"`
	BizScene       string     `validate:"required" json:"biz_scene"`
	OrderTitle     string     `json:"order_title"`
	Remark         string     `json:"remark"`
	PayeeInfo      *PayeeInfo `json:"payee_info"`
	BusinessParams string     `json:"business_params"`
}

type OrderResponse struct {
	Code    vo.Code `json:"code"`
	Msg     string  `json:"msg"`
	SubCode string  `json:"sub_code"`
	SubMsg  string  `json:"sub_msg"`

	OutBizNo       string `json:"out_biz_no"`
	OrderId        string `json:"order_id"`
	PayFundOrderId string `json:"pay_fund_order_id"`
	Status         string `json:"status"`
	TransDate      int32  `json:"trans_date"`
	SettleSerialNo int32  `json:"settle_serial_no"`
}

type OrderResp struct {
	Response OrderResponse `json:"alipay_fund_trans_uni_transfer_response"`
	Sign     string        `json:"sign"`
}

func (o *OrderResp) GetMsg() string {
	if o.Response.Code.IsSuccess() {
		return o.Response.Msg
	}
	return fmt.Sprintf(
		"code:[%s],msg:[%s],subCode:[%s],subMsg[%s]",
		o.Response.Code, o.Response.Msg, o.Response.SubCode, o.Response.SubMsg,
	)
}

func (o *OrderResp) GetOrderStatus() proto.Status {
	if o.Response.Code.IsSuccess() {
		return proto.Status_ING
	}
	return proto.Status_FAIL
}
